@@ -1,10 +1,9 @@
 //go:build sam && atsamd21 && xiao
-// +build sam,atsamd21,xiao
 
 package machine
 
 // used to reset into bootloader
-const RESET_MAGIC_VALUE = 0xf01669ef
+const resetMagicValue = 0xf01669ef
 
 // GPIO Pins
 const (
@@ -97,3 +96,7 @@ var (
 	usb_VID uint16 = 0x2886
 	usb_PID uint16 = 0x802F
 )
+
+var (
+	DefaultUART = UART1
+)
