@@ -2,20 +2,23 @@
 
 package machine
 
+import (
+	"crypto/rand"
+)
+
 // Dummy machine package that calls out to external functions.
 
 const deviceName = "generic"
 
 var (
-	UART0 = &UART{0}
-	USB   = &UART{100}
+	USB = &UART{100}
 )
 
 // The Serial port always points to the default UART in a simulated environment.
 //
 // TODO: perhaps this should be a special serial object that outputs via WASI
 // stdout calls.
-var Serial = UART0
+var Serial = hardwareUART0
 
 const (
 	PinInput PinMode = iota
@@ -57,8 +60,9 @@ type SPIConfig struct {
 	Mode      uint8
 }
 
-func (spi SPI) Configure(config SPIConfig) {
+func (spi SPI) Configure(config SPIConfig) error {
 	spiConfigure(spi.Bus, config.SCK, config.SDO, config.SDI)
+	return nil
 }
 
 // Transfer writes/reads a single byte using the SPI interface.
@@ -66,12 +70,47 @@ func (spi SPI) Transfer(w byte) (byte, error) {
 	return spiTransfer(spi.Bus, w), nil
 }
 
+// Tx handles read/write operation for SPI interface. Since SPI is a synchronous write/read
+// interface, there must always be the same number of bytes written as bytes read.
+// The Tx method knows about this, and offers a few different ways of calling it.
+//
+// This form sends the bytes in tx buffer, putting the resulting bytes read into the rx buffer.
+// Note that the tx and rx buffers must be the same size:
+//
+//	spi.Tx(tx, rx)
+//
+// This form sends the tx buffer, ignoring the result. Useful for sending "commands" that return zeros
+// until all the bytes in the command packet have been received:
+//
+//	spi.Tx(tx, nil)
+//
+// This form sends zeros, putting the result into the rx buffer. Good for reading a "result packet":
+//
+//	spi.Tx(nil, rx)
+func (spi SPI) Tx(w, r []byte) error {
+	var wptr, rptr *byte
+	var wlen, rlen int
+	if len(w) != 0 {
+		wptr = &w[0]
+		wlen = len(w)
+	}
+	if len(r) != 0 {
+		rptr = &r[0]
+		rlen = len(r)
+	}
+	spiTX(spi.Bus, wptr, wlen, rptr, rlen)
+	return nil
+}
+
 //export __tinygo_spi_configure
 func spiConfigure(bus uint8, sck Pin, SDO Pin, SDI Pin)
 
 //export __tinygo_spi_transfer
 func spiTransfer(bus uint8, w uint8) uint8
 
+//export __tinygo_spi_tx
+func spiTX(bus uint8, wptr *byte, wlen int, rptr *byte, rlen int) uint8
+
 // InitADC enables support for ADC peripherals.
 func InitADC() {
 	// Nothing to do here.
@@ -107,9 +146,25 @@ func (i2c *I2C) Configure(config I2CConfig) error {
 	return nil
 }
 
+// SetBaudRate sets the I2C frequency.
+func (i2c *I2C) SetBaudRate(br uint32) error {
+	i2cSetBaudRate(i2c.Bus, br)
+	return nil
+}
+
 // Tx does a single I2C transaction at the specified address.
 func (i2c *I2C) Tx(addr uint16, w, r []byte) error {
-	i2cTransfer(i2c.Bus, &w[0], len(w), &r[0], len(r))
+	var wptr, rptr *byte
+	var wlen, rlen int
+	if len(w) != 0 {
+		wptr = &w[0]
+		wlen = len(w)
+	}
+	if len(r) != 0 {
+		rptr = &r[0]
+		rlen = len(r)
+	}
+	i2cTransfer(i2c.Bus, wptr, wlen, rptr, rlen)
 	// TODO: do something with the returned error code.
 	return nil
 }
@@ -117,6 +172,9 @@ func (i2c *I2C) Tx(addr uint16, w, r []byte) error {
 //export __tinygo_i2c_configure
 func i2cConfigure(bus uint8, scl Pin, sda Pin)
 
+//export __tinygo_i2c_set_baud_rate
+func i2cSetBaudRate(bus uint8, br uint32)
+
 //export __tinygo_i2c_transfer
 func i2cTransfer(bus uint8, w *byte, wlen int, r *byte, rlen int) int
 
@@ -166,6 +224,11 @@ func uartRead(bus uint8, buf *byte, bufLen int) int
 //export __tinygo_uart_write
 func uartWrite(bus uint8, buf *byte, bufLen int) int
 
+var (
+	hardwareUART0 = &UART{0}
+	hardwareUART1 = &UART{1}
+)
+
 // Some objects used by Atmel SAM D chips (samd21, samd51).
 // Defined here (without build tag) for convenience.
 var (
@@ -194,3 +257,13 @@ var (
 	sercomSPIM6 = SPI{6}
 	sercomSPIM7 = SPI{7}
 )
+
+// GetRNG returns 32 bits of random data from the WASI random source.
+func GetRNG() (uint32, error) {
+	var buf [4]byte
+	_, err := rand.Read(buf[:])
+	if err != nil {
+		return 0, err
+	}
+	return uint32(buf[0])<<0 | uint32(buf[1])<<8 | uint32(buf[2])<<16 | uint32(buf[3])<<24, nil
+}
