@@ -124,10 +124,9 @@ func (v Value) IsZero() bool {
 	case Uint, Uint8, Uint16, Uint32, Uint64, Uintptr:
 		return v.Uint() == 0
 	case Float32, Float64:
-		return math.Float64bits(v.Float()) == 0
+		return v.Float() == 0
 	case Complex64, Complex128:
-		c := v.Complex()
-		return math.Float64bits(real(c)) == 0 && math.Float64bits(imag(c)) == 0
+		return v.Complex() == 0
 	case Array:
 		for i := 0; i < v.Len(); i++ {
 			if !v.Index(i).IsZero() {
@@ -141,7 +140,7 @@ func (v Value) IsZero() bool {
 		return v.Len() == 0
 	case Struct:
 		for i := 0; i < v.NumField(); i++ {
-			if !v.Field(i).IsZero() {
+			if !v.Field(i).IsZero() && v.Type().Field(i).Name != "_" {
 				return false
 			}
 		}
@@ -1087,6 +1086,13 @@ func (v Value) Set(x Value) {
 	}
 
 	if v.typecode.Kind() == Interface && x.typecode.Kind() != Interface {
+		// move the value of x back into the interface, if possible
+		if x.isIndirect() && x.typecode.Size() <= unsafe.Sizeof(uintptr(0)) {
+			var value uintptr
+			memcpy(unsafe.Pointer(&value), x.value, x.typecode.Size())
+			x.value = unsafe.Pointer(value)
+		}
+
 		intf := composeInterface(unsafe.Pointer(x.typecode), x.value)
 		x = Value{
 			typecode: v.typecode,
@@ -1572,8 +1578,8 @@ type funcHeader struct {
 
 type SliceHeader struct {
 	Data uintptr
-	Len  uintptr
-	Cap  uintptr
+	Len  intw
+	Cap  intw
 }
 
 // Slice header that matches the underlying structure. Used for when we switch
@@ -1586,7 +1592,7 @@ type sliceHeader struct {
 
 type StringHeader struct {
 	Data uintptr
-	Len  uintptr
+	Len  intw
 }
 
 // Like sliceHeader, this type is used internally to make sure pointer and
@@ -1596,6 +1602,16 @@ type stringHeader struct {
 	len  uintptr
 }
 
+// Verify SliceHeader and StringHeader sizes.
+// See https://github.com/tinygo-org/tinygo/pull/4156
+// and https://github.com/tinygo-org/tinygo/issues/1284.
+var (
+	_ [unsafe.Sizeof([]byte{})]byte = [unsafe.Sizeof(SliceHeader{})]byte{}
+	_ [unsafe.Sizeof([]byte{})]byte = [unsafe.Sizeof(sliceHeader{})]byte{}
+	_ [unsafe.Sizeof("")]byte       = [unsafe.Sizeof(StringHeader{})]byte{}
+	_ [unsafe.Sizeof("")]byte       = [unsafe.Sizeof(stringHeader{})]byte{}
+)
+
 type ValueError struct {
 	Method string
 	Kind   Kind
@@ -2005,6 +2021,10 @@ func (v Value) Call(in []Value) []Value {
 	panic("unimplemented: (reflect.Value).Call()")
 }
 
+func (v Value) CallSlice(in []Value) []Value {
+	panic("unimplemented: (reflect.Value).CallSlice()")
+}
+
 func (v Value) Method(i int) Value {
 	panic("unimplemented: (reflect.Value).Method()")
 }
