@@ -1,5 +1,7 @@
 package syscall
 
+import "internal/itoa"
+
 // Most code here has been copied from the Go sources:
 //   https://github.com/golang/go/blob/go1.12/src/syscall/syscall_js.go
 // It has the following copyright note:
@@ -11,14 +13,15 @@ package syscall
 // An Errno is an unsigned number describing an error condition.
 // It implements the error interface. The zero Errno is by convention
 // a non-error, so code to convert from Errno to error should use:
-//      err = nil
-//      if errno != 0 {
-//              err = errno
-//      }
+//
+//	err = nil
+//	if errno != 0 {
+//	        err = errno
+//	}
 type Errno uintptr
 
 func (e Errno) Error() string {
-	return "errno " + itoa(int(e))
+	return "errno " + itoa.Itoa(int(e))
 }
 
 func (e Errno) Temporary() bool {
