@@ -1,5 +1,4 @@
 //go:build darwin
-// +build darwin
 
 package syscall
 
@@ -18,6 +17,11 @@ import (
 //export fdopendir$INODE64
 func libc_fdopendir(fd int32) unsafe.Pointer
 
+// int closedir(struct DIR * buf);
+//
+//export closedir
+func libc_closedir(unsafe.Pointer) int32
+
 // int readdir_r(struct DIR * buf, struct dirent *entry, struct dirent **result);
 //
 //export readdir_r$INODE64
